@@ -1,5 +1,6 @@
 import numpy as np
 
+from autoarray.structures import grids
 from autoarray.util import array_util, grid_util
 
 
@@ -8,10 +9,6 @@ class Geometry:
 
         self.mask = mask
 
-    @property
-    def mapping(self):
-        return self.mask.mapping
-
     @property
     def regions(self):
         return self.mask.regions
@@ -67,7 +64,7 @@ class Geometry:
     @property
     @array_util.Memoizer()
     def mask_centre(self):
-        return grid_util.grid_centre_from_grid_1d(grid_1d=self.masked_grid)
+        return grid_util.grid_centre_from(grid_1d=self.masked_grid)
 
     @property
     def shape_2d_scaled(self):
@@ -118,27 +115,29 @@ class Geometry:
         This is defined from the top-left corner, such that the first pixel at location [0, 0] will have a negative x \
         value y value in arc seconds.
         """
-        grid_1d = grid_util.grid_1d_via_shape_2d(
+        grid_1d = grid_util.grid_1d_via_shape_2d_from(
             shape_2d=self.mask.shape,
             pixel_scales=self.mask.pixel_scales,
             sub_size=1,
             origin=self.mask.origin,
         )
 
-        return self.mask.regions.unmasked_mask.mapping.grid_stored_1d_from_grid_1d(
-            grid_1d=grid_1d
+        return grids.Grid(
+            grid=grid_1d,
+            mask=self.mask.regions.unmasked_mask.mask_sub_1,
+            store_in_1d=True,
         )
 
     @property
     def masked_grid(self):
 
-        grid_1d = grid_util.grid_1d_via_mask_2d(
-            mask_2d=self.mask,
+        grid_1d = grid_util.grid_1d_via_mask_from(
+            mask=self.mask,
             pixel_scales=self.mask.pixel_scales,
             sub_size=1,
             origin=self.mask.origin,
         )
-        return self.mask.mapping.grid_stored_1d_from_grid_1d(grid_1d=grid_1d)
+        return grids.Grid(grid=grid_1d, mask=self.mask.mask_sub_1, store_in_1d=True)
 
     @property
     def edge_grid(self):
@@ -147,8 +146,8 @@ class Geometry:
         an annulus mask).
         """
         edge_grid_1d = self.masked_grid[self.regions._edge_1d_indexes]
-        return self.regions.edge_mask.mapping.grid_stored_1d_from_grid_1d(
-            grid_1d=edge_grid_1d
+        return grids.Grid(
+            grid=edge_grid_1d, mask=self.regions.edge_mask.mask_sub_1, store_in_1d=True
         )
 
     @property
@@ -158,8 +157,10 @@ class Geometry:
         an annulus mask).
         """
         border_grid_1d = self.masked_grid[self.regions._border_1d_indexes]
-        return self.regions.border_mask.mapping.grid_stored_1d_from_grid_1d(
-            grid_1d=border_grid_1d
+        return grids.Grid(
+            grid=border_grid_1d,
+            mask=self.regions.border_mask.mask_sub_1,
+            store_in_1d=True,
         )
 
     def grid_pixels_from_grid_scaled_1d(self, grid_scaled_1d):
@@ -177,13 +178,15 @@ class Geometry:
         grid_scaled_1d: ndarray
             A grid of (y,x) coordinates in arc seconds.
         """
-        grid_pixels_1d = grid_util.grid_pixels_1d_from_grid_scaled_1d_shape_2d_and_pixel_scales(
+        grid_pixels_1d = grid_util.grid_pixels_1d_from(
             grid_scaled_1d=grid_scaled_1d,
             shape_2d=self.mask.shape,
             pixel_scales=self.mask.pixel_scales,
             origin=self.mask.origin,
         )
-        return self.mask.mapping.grid_stored_1d_from_grid_1d(grid_1d=grid_pixels_1d)
+        return grids.Grid(
+            grid=grid_pixels_1d, mask=self.mask.mask_sub_1, store_in_1d=True
+        )
 
     def grid_pixel_centres_from_grid_scaled_1d(self, grid_scaled_1d):
         """Convert a grid of (y,x) arc second coordinates to a grid of (y,x) pixel values. Pixel coordinates are \
@@ -200,16 +203,17 @@ class Geometry:
         grid_scaled_1d: ndarray
             The grid of (y,x) coordinates in arc seconds.
         """
-        grid_pixel_centres_1d = grid_util.grid_pixel_centres_1d_from_grid_scaled_1d_shape_2d_and_pixel_scales(
+        grid_pixel_centres_1d = grid_util.grid_pixel_centres_1d_from(
             grid_scaled_1d=grid_scaled_1d,
             shape_2d=self.mask.shape,
             pixel_scales=self.mask.pixel_scales,
             origin=self.mask.origin,
-        ).astype(
-            "int"
-        )
-        return self.mask.mapping.grid_stored_1d_from_grid_1d(
-            grid_1d=grid_pixel_centres_1d
+        ).astype("int")
+
+        return grids.Grid(
+            grid=grid_pixel_centres_1d,
+            mask=self.regions.edge_mask.mask_sub_1,
+            store_in_1d=True,
         )
 
     def grid_pixel_indexes_from_grid_scaled_1d(self, grid_scaled_1d):
@@ -231,16 +235,16 @@ class Geometry:
         grid_scaled_1d: ndarray
             The grid of (y,x) coordinates in arc seconds.
         """
-        grid_pixel_indexes_1d = grid_util.grid_pixel_indexes_1d_from_grid_scaled_1d_shape_2d_and_pixel_scales(
+        grid_pixel_indexes_1d = grid_util.grid_pixel_indexes_1d_from(
             grid_scaled_1d=grid_scaled_1d,
             shape_2d=self.mask.shape,
             pixel_scales=self.mask.pixel_scales,
             origin=self.mask.origin,
-        ).astype(
-            "int"
-        )
-        return self.mask.mapping.grid_stored_1d_from_grid_1d(
-            grid_1d=grid_pixel_indexes_1d
+        ).astype("int")
+        return grids.Grid(
+            grid=grid_pixel_indexes_1d,
+            mask=self.regions.edge_mask.mask_sub_1,
+            store_in_1d=True,
         )
 
     def grid_scaled_from_grid_pixels_1d(self, grid_pixels_1d):
@@ -257,13 +261,17 @@ class Geometry:
         grid_pixels_1d : ndarray
             The grid of (y,x) coordinates in pixels.
         """
-        grid_scaled_1d = grid_util.grid_scaled_1d_from_grid_pixels_1d_shape_2d_and_pixel_scales(
+        grid_scaled_1d = grid_util.grid_scaled_1d_from(
             grid_pixels_1d=grid_pixels_1d,
             shape_2d=self.mask.shape,
             pixel_scales=self.mask.pixel_scales,
             origin=self.mask.origin,
         )
-        return self.mask.mapping.grid_stored_1d_from_grid_1d(grid_1d=grid_scaled_1d)
+        return grids.Grid(
+            grid=grid_scaled_1d,
+            mask=self.regions.edge_mask.mask_sub_1,
+            store_in_1d=True,
+        )
 
     @property
     def sub_size(self):
@@ -273,7 +281,7 @@ class Geometry:
         self, grid_pixels_1d, shape_2d
     ):
 
-        grid_scaled_1d = grid_util.grid_scaled_1d_from_grid_pixels_1d_shape_2d_and_pixel_scales(
+        grid_scaled_1d = grid_util.grid_scaled_1d_from(
             grid_pixels_1d=grid_pixels_1d,
             shape_2d=shape_2d,
             pixel_scales=(
@@ -286,18 +294,22 @@ class Geometry:
         grid_scaled_1d[:, 0] -= self.mask.pixel_scales[0] / (2.0 * self.mask.sub_size)
         grid_scaled_1d[:, 1] += self.mask.pixel_scales[1] / (2.0 * self.mask.sub_size)
 
-        return self.mask.mapping.grid_stored_1d_from_grid_1d(grid_1d=grid_scaled_1d)
+        return grids.Grid(
+            grid=grid_scaled_1d,
+            mask=self.regions.edge_mask.mask_sub_1,
+            store_in_1d=True,
+        )
 
     @property
     def masked_sub_grid(self):
-        sub_grid_1d = grid_util.grid_1d_via_mask_2d(
-            mask_2d=self.mask,
+        sub_grid_1d = grid_util.grid_1d_via_mask_from(
+            mask=self.mask,
             pixel_scales=self.mask.pixel_scales,
             sub_size=self.mask.sub_size,
             origin=self.mask.origin,
         )
-        return self.mask.mapping.grid_stored_1d_from_sub_grid_1d(
-            sub_grid_1d=sub_grid_1d
+        return grids.Grid(
+            grid=sub_grid_1d, mask=self.regions.edge_mask.mask_sub_1, store_in_1d=True
         )
 
     @property
