@@ -145,7 +145,7 @@ class Inversion:
 
     @staticmethod
     def log_determinant_of_matrix_cholesky(matrix):
-        """There are two terms in the inversion's Bayesian likelihood function which require the log determinant of \
+        """There are two terms in the inversion's Bayesian log likelihood function which require the log determinant of \
         a matrix. These are (Nightingale & Dye 2015, Nightingale, Dye and Massey 2018):
 
         ln[det(F + H)] = ln[det(curvature_reg_matrix)]
@@ -171,11 +171,9 @@ class Inversion:
 
     @property
     def brightest_reconstruction_pixel_centre(self):
-        return grids.Coordinates(
+        return grids.GridCoordinates(
             coordinates=[
-                tuple(
-                    self.mapper.pixelization_grid[self.brightest_reconstruction_pixel]
-                )
+                self.mapper.pixelization_grid[self.brightest_reconstruction_pixel]
             ]
         )
 
@@ -192,7 +190,7 @@ class InversionImaging(Inversion):
         curvature_reg_matrix,
         reconstruction,
     ):
-        """ An inversion, which given an input image and noise-map reconstructs the image using a linear inversion, \
+        """ An inversion, which given an input image and noise map reconstructs the image using a linear inversion, \
         including a convolution that accounts for blurring.
 
         The inversion uses a 2D pixelization to perform the reconstruction by util each pixelization pixel to a \
@@ -204,7 +202,7 @@ class InversionImaging(Inversion):
         image_1d : ndarray
             Flattened 1D array of the observed image the inversion is fitting.
         noise_map : ndarray
-            Flattened 1D array of the noise-map used by the inversion during the fit.   
+            Flattened 1D array of the noise map used by the inversion during the fit.
         convolver : imaging.convolution.Convolver
             The convolver used to blur the util matrix with the PSF.
         mapper : inversion.mappers.Mapper
@@ -249,13 +247,13 @@ class InversionImaging(Inversion):
             mapping_matrix=mapper.mapping_matrix
         )
 
-        data_vector = inversion_util.data_vector_from_blurred_mapping_matrix_and_data(
+        data_vector = inversion_util.data_vector_via_blurred_mapping_matrix_from(
             blurred_mapping_matrix=blurred_mapping_matrix,
             image=image,
             noise_map=noise_map,
         )
 
-        curvature_matrix = inversion_util.curvature_matrix_from_blurred_mapping_matrix(
+        curvature_matrix = inversion_util.curvature_matrix_via_blurred_mapping_matrix_from(
             blurred_mapping_matrix=blurred_mapping_matrix, noise_map=noise_map
         )
 
@@ -283,17 +281,20 @@ class InversionImaging(Inversion):
 
     @property
     def mapped_reconstructed_image(self):
-        reconstructed_image = inversion_util.mapped_reconstructed_data_from_mapping_matrix_and_reconstruction(
+        reconstructed_image = inversion_util.mapped_reconstructed_data_from(
             mapping_matrix=self.blurred_mapping_matrix,
             reconstruction=self.reconstruction,
         )
-        return self.mapper.grid.mapping.array_stored_1d_from_array_1d(
-            array_1d=reconstructed_image
+
+        return arrays.Array(
+            array=reconstructed_image,
+            mask=self.mapper.grid.mask.mask_sub_1,
+            store_in_1d=True,
         )
 
     @property
     def residual_map(self):
-        return inversion_util.inversion_residual_map_from_pixelization_values_and_data(
+        return inversion_util.inversion_residual_map_from(
             pixelization_values=self.reconstruction,
             data=self.image,
             mask_1d_index_for_sub_mask_1d_index=self.mapper.grid.mask.regions._mask_1d_index_for_sub_mask_1d_index,
@@ -302,7 +303,7 @@ class InversionImaging(Inversion):
 
     @property
     def normalized_residual_map(self):
-        return inversion_util.inversion_normalized_residual_map_from_pixelization_values_and_reconstructed_data_1d(
+        return inversion_util.inversion_normalized_residual_map_from(
             pixelization_values=self.reconstruction,
             data=self.image,
             noise_map_1d=self.noise_map,
@@ -312,7 +313,7 @@ class InversionImaging(Inversion):
 
     @property
     def chi_squared_map(self):
-        return inversion_util.inversion_chi_squared_map_from_pixelization_values_and_reconstructed_data_1d(
+        return inversion_util.inversion_chi_squared_map_from(
             pixelization_values=self.reconstruction,
             data=self.image,
             noise_map_1d=self.noise_map,
@@ -333,7 +334,7 @@ class InversionInterferometer(Inversion):
         curvature_reg_matrix,
         reconstruction,
     ):
-        """ An inversion, which given an input image and noise-map reconstructs the image using a linear inversion, \
+        """ An inversion, which given an input image and noise map reconstructs the image using a linear inversion, \
         including a convolution that accounts for blurring.
 
         The inversion uses a 2D pixelization to perform the reconstruction by util each pixelization pixel to a \
@@ -345,7 +346,7 @@ class InversionInterferometer(Inversion):
         image_1d : ndarray
             Flattened 1D array of the observed image the inversion is fitting.
         noise_map : ndarray
-            Flattened 1D array of the noise-map used by the inversion during the fit.   
+            Flattened 1D array of the noise map used by the inversion during the fit.
         convolver : imaging.convolution.Convolver
             The convolver used to blur the util matrix with the PSF.
         mapper : inversion.mappers.Mapper
@@ -390,24 +391,24 @@ class InversionInterferometer(Inversion):
             mapping_matrix=mapper.mapping_matrix
         )
 
-        real_data_vector = inversion_util.data_vector_from_transformed_mapping_matrix_and_data(
+        real_data_vector = inversion_util.data_vector_via_transformed_mapping_matrix_from(
             transformed_mapping_matrix=transformed_mapping_matrices[0],
             visibilities=visibilities[:, 0],
             noise_map=noise_map[:, 0],
         )
 
-        imag_data_vector = inversion_util.data_vector_from_transformed_mapping_matrix_and_data(
+        imag_data_vector = inversion_util.data_vector_via_transformed_mapping_matrix_from(
             transformed_mapping_matrix=transformed_mapping_matrices[1],
             visibilities=visibilities[:, 1],
             noise_map=noise_map[:, 1],
         )
 
-        real_curvature_matrix = inversion_util.curvature_matrix_from_transformed_mapping_matrix(
+        real_curvature_matrix = inversion_util.curvature_matrix_via_transformed_mapping_matrix_from(
             transformed_mapping_matrix=transformed_mapping_matrices[0],
             noise_map=noise_map[:, 0],
         )
 
-        imag_curvature_matrix = inversion_util.curvature_matrix_from_transformed_mapping_matrix(
+        imag_curvature_matrix = inversion_util.curvature_matrix_via_transformed_mapping_matrix_from(
             transformed_mapping_matrix=transformed_mapping_matrices[1],
             noise_map=noise_map[:, 1],
         )
@@ -416,13 +417,11 @@ class InversionInterferometer(Inversion):
             mapper=mapper
         )
 
-        real_curvature_reg_matrix = np.add(real_curvature_matrix, regularization_matrix)
-        imag_curvature_reg_matrix = np.add(imag_curvature_matrix, regularization_matrix)
-
         data_vector = np.add(real_data_vector, imag_data_vector)
-        curvature_reg_matrix = np.add(
-            real_curvature_reg_matrix, imag_curvature_reg_matrix
-        )
+
+        curvature_matrix = np.add(real_curvature_matrix, imag_curvature_matrix)
+
+        curvature_reg_matrix = np.add(curvature_matrix, regularization_matrix)
 
         try:
             values = np.linalg.solve(curvature_reg_matrix, data_vector)
@@ -442,23 +441,25 @@ class InversionInterferometer(Inversion):
 
     @property
     def mapped_reconstructed_image(self):
-        mapped_reconstructed_image = inversion_util.mapped_reconstructed_data_from_mapping_matrix_and_reconstruction(
+        mapped_reconstructed_image = inversion_util.mapped_reconstructed_data_from(
             mapping_matrix=self.mapper.mapping_matrix,
             reconstruction=self.reconstruction,
         )
 
-        return self.mapper.grid.mapping.array_stored_1d_from_array_1d(
-            array_1d=mapped_reconstructed_image
+        return arrays.Array(
+            array=mapped_reconstructed_image,
+            mask=self.mapper.grid.mask.mask_sub_1,
+            store_in_1d=True,
         )
 
     @property
     def mapped_reconstructed_visibilities(self):
-        real_visibilities = inversion_util.mapped_reconstructed_data_from_mapping_matrix_and_reconstruction(
+        real_visibilities = inversion_util.mapped_reconstructed_data_from(
             mapping_matrix=self.transformed_mapping_matrices[0],
             reconstruction=self.reconstruction,
         )
 
-        imag_visibilities = inversion_util.mapped_reconstructed_data_from_mapping_matrix_and_reconstruction(
+        imag_visibilities = inversion_util.mapped_reconstructed_data_from(
             mapping_matrix=self.transformed_mapping_matrices[1],
             reconstruction=self.reconstruction,
         )
