@@ -132,11 +132,13 @@ class TestImaging:
             image_path=test_data_dir + "3x3_ones.fits",
             psf_path=test_data_dir + "3x3_twos.fits",
             noise_map_path=test_data_dir + "3x3_threes.fits",
+            positions_path=test_data_dir + "positions.dat",
         )
 
         assert (imaging.image.in_2d == np.ones((3, 3))).all()
         assert (imaging.psf.in_2d == (1.0 / 9.0) * np.ones((3, 3))).all()
         assert (imaging.noise_map.in_2d == 3.0 * np.ones((3, 3))).all()
+        assert imaging.positions.in_list == [[(1.0, 1.0), (2.0, 2.0)]]
 
         assert imaging.pixel_scales == (0.1, 0.1)
         assert imaging.psf.mask.pixel_scales == (0.1, 0.1)
@@ -222,48 +224,54 @@ class TestMaskedImaging:
         assert (masked_imaging_7x7.psf.in_2d == (1.0 / 9.0) * np.ones((3, 3))).all()
         assert masked_imaging_7x7.psf_shape_2d == (3, 3)
 
-    def test__blurring_grid(
-        self, imaging_7x7, sub_mask_7x7, grid_7x7, sub_grid_7x7, blurring_grid_7x7
+    def test__grid(
+        self,
+        imaging_7x7,
+        sub_mask_7x7,
+        grid_7x7,
+        sub_grid_7x7,
+        blurring_grid_7x7,
+        grid_iterate_7x7,
     ):
-        masked_imaging_7x7 = aa.MaskedImaging(imaging=imaging_7x7, mask=sub_mask_7x7)
+        masked_imaging_7x7 = aa.MaskedImaging(
+            imaging=imaging_7x7, mask=sub_mask_7x7, grid_class=aa.Grid
+        )
 
+        assert isinstance(masked_imaging_7x7.grid, aa.Grid)
         assert (masked_imaging_7x7.grid.in_1d_binned == grid_7x7).all()
         assert (masked_imaging_7x7.grid.in_1d == sub_grid_7x7).all()
+        assert isinstance(masked_imaging_7x7.blurring_grid, aa.Grid)
         assert (masked_imaging_7x7.blurring_grid.in_1d == blurring_grid_7x7).all()
 
-    def test__pixel_scale_interpolation_grid_input__grids_include_interpolator_on_blurring_grid(
-        self, imaging_7x7, sub_mask_7x7
-    ):
+        masked_imaging_7x7 = aa.MaskedImaging(
+            imaging=imaging_7x7, mask=sub_mask_7x7, grid_class=aa.GridIterate
+        )
+
+        assert isinstance(masked_imaging_7x7.grid, aa.GridIterate)
+        assert (masked_imaging_7x7.grid.in_1d_binned == grid_iterate_7x7).all()
+        assert isinstance(masked_imaging_7x7.blurring_grid, aa.Grid)
+        assert (masked_imaging_7x7.blurring_grid.in_1d == blurring_grid_7x7).all()
 
         masked_imaging_7x7 = aa.MaskedImaging(
-            imaging=imaging_7x7, mask=sub_mask_7x7, pixel_scale_interpolation_grid=1.0
+            imaging=imaging_7x7,
+            mask=sub_mask_7x7,
+            grid_class=aa.GridInterpolate,
+            pixel_scales_interp=1.0,
         )
 
-        grid = aa.MaskedGrid.from_mask(mask=sub_mask_7x7)
-        new_grid = grid.new_grid_with_interpolator(pixel_scale_interpolation_grid=1.0)
+        grid = aa.GridInterpolate.from_mask(mask=sub_mask_7x7, pixel_scales_interp=1.0)
 
         blurring_grid = grid.blurring_grid_from_kernel_shape(kernel_shape_2d=(3, 3))
-        new_blurring_grid = blurring_grid.new_grid_with_interpolator(
-            pixel_scale_interpolation_grid=1.0
-        )
 
-        assert (masked_imaging_7x7.grid == new_grid).all()
-        assert (
-            masked_imaging_7x7.grid.interpolator.vtx == new_grid.interpolator.vtx
-        ).all()
-        assert (
-            masked_imaging_7x7.grid.interpolator.wts == new_grid.interpolator.wts
-        ).all()
+        assert isinstance(masked_imaging_7x7.grid, aa.GridInterpolate)
+        assert (masked_imaging_7x7.grid == grid).all()
+        assert (masked_imaging_7x7.grid.vtx == grid.vtx).all()
+        assert (masked_imaging_7x7.grid.wts == grid.wts).all()
 
-        assert (masked_imaging_7x7.blurring_grid == new_blurring_grid).all()
-        assert (
-            masked_imaging_7x7.blurring_grid.interpolator.vtx
-            == new_blurring_grid.interpolator.vtx
-        ).all()
-        assert (
-            masked_imaging_7x7.blurring_grid.interpolator.wts
-            == new_blurring_grid.interpolator.wts
-        ).all()
+        assert isinstance(masked_imaging_7x7.blurring_grid, aa.GridInterpolate)
+        assert (masked_imaging_7x7.blurring_grid == blurring_grid).all()
+        assert (masked_imaging_7x7.blurring_grid.vtx == blurring_grid.vtx).all()
+        assert (masked_imaging_7x7.blurring_grid.wts == blurring_grid.wts).all()
 
     def test__psf_and_convolvers(self, imaging_7x7, sub_mask_7x7):
 
@@ -300,6 +308,24 @@ class TestMaskedImaging:
         assert (masked_imaging.image == np.array([1.0])).all()
         assert (masked_imaging.noise_map == np.array([2.0])).all()
 
+    def test__modified_image_and_noise_map(
+        self, image_7x7, noise_map_7x7, imaging_7x7, sub_mask_7x7
+    ):
+
+        masked_imaging_7x7 = aa.MaskedImaging(imaging=imaging_7x7, mask=sub_mask_7x7)
+
+        image_7x7[0] = 10.0
+        noise_map_7x7[0] = 11.0
+
+        masked_imaging_7x7 = masked_imaging_7x7.modify_image_and_noise_map(
+            image=image_7x7, noise_map=noise_map_7x7
+        )
+
+        assert masked_imaging_7x7.image.in_1d[0] == 10.0
+        assert masked_imaging_7x7.image.in_2d[0, 0] == 10.0
+        assert masked_imaging_7x7.noise_map.in_1d[0] == 11.0
+        assert masked_imaging_7x7.noise_map.in_2d[0, 0] == 11.0
+
 
 class TestSimulatorImaging:
     def test__from_image__all_features_off(self):
