@@ -146,14 +146,14 @@ class TestReconstructedDataVectorAndImage:
         matrix_shape = (3, 3)
 
         mask = aa.Mask.manual(
-            mask_2d=np.array(
+            mask=np.array(
                 [[True, True, True], [False, False, False], [True, True, True]]
             ),
             pixel_scales=1.0,
             sub_size=1,
         )
 
-        grid = aa.MaskedGrid.from_mask(mask=mask)
+        grid = aa.Grid.from_mask(mask=mask)
 
         inversion = inversions.InversionImaging.from_data_mapper_and_regularization(
             image=np.ones(9),
@@ -190,14 +190,14 @@ class TestReconstructedDataVectorAndImage:
         matrix_shape = (3, 3)
 
         mask = aa.Mask.manual(
-            mask_2d=np.array(
+            mask=np.array(
                 [[True, True, True], [False, False, False], [True, True, True]]
             ),
             pixel_scales=1.0,
             sub_size=1,
         )
 
-        grid = aa.MaskedGrid.from_mask(mask=mask)
+        grid = aa.Grid.from_mask(mask=mask)
 
         inversion = inversions.InversionImaging.from_data_mapper_and_regularization(
             image=np.ones(9),
@@ -242,17 +242,17 @@ class TestBrightestPixel:
             convolver=mock_inversion.MockConvolver(matrix_shape),
             mapper=mock_inversion.MockMapper(
                 matrix_shape,
-                pixelization_grid=aa.GridIrregular.manual_1d(
-                    [[1.0, 2.0], [3.0, 4.0], [5.0, 6.0]]
+                pixelization_grid=aa.GridVoronoi.manual_1d(
+                    [[1.0, 2.0], [3.0, 4.0], [5.0, 6.0], [5.0, 0.0]]
                 ),
             ),
             regularization=mock_inversion.MockRegularization(matrix_shape),
         )
 
-        inversion.reconstruction = np.array([2.0, 3.0, 5.0])
+        inversion.reconstruction = np.array([2.0, 3.0, 5.0, 0.0])
 
         assert inversion.brightest_reconstruction_pixel == 2
-        assert inversion.brightest_reconstruction_pixel_centre == [(5.0, 6.0)]
+        assert inversion.brightest_reconstruction_pixel_centre.in_list == [[(5.0, 6.0)]]
 
 
 from autoconf import conf
@@ -264,7 +264,7 @@ directory = path.dirname(path.realpath(__file__))
 
 
 class TestInterpolatedReconstruction:
-    def test__interpolation_reconstruction__config_is_image_grid__grid_as_mapper_with_good_interpolation(
+    def test__interp_reconstruction__config_is_image_grid__grid_as_mapper_with_good_interp(
         self
     ):
 
@@ -276,7 +276,7 @@ class TestInterpolatedReconstruction:
         matrix_shape = (3, 3)
 
         mask = aa.Mask.manual(
-            mask_2d=np.array(
+            mask=np.array(
                 [
                     [True, True, True, True, True],
                     [True, True, False, False, True],
@@ -289,7 +289,7 @@ class TestInterpolatedReconstruction:
             sub_size=2,
         )
 
-        grid = aa.MaskedGrid.from_mask(mask=mask)
+        grid = aa.Grid.from_mask(mask=mask)
 
         pixelization_grid = aa.Grid.uniform(
             shape_2d=(3, 3), pixel_scales=1.0, sub_size=1
@@ -327,7 +327,7 @@ class TestInterpolatedReconstruction:
             (1.0, 1.0), 1.0e-4
         )
 
-    def test__interpolation_errors__also_on_image_grid__interpolates_values(self):
+    def test__interp_errors__also_on_image_grid__interpolates_values(self):
 
         conf.instance = aa.conf.Config(
             path.join(directory, "../files/inversion_image_grid"),
@@ -337,7 +337,7 @@ class TestInterpolatedReconstruction:
         matrix_shape = (3, 3)
 
         mask = aa.Mask.manual(
-            mask_2d=np.array(
+            mask=np.array(
                 [
                     [True, True, True, True, True],
                     [True, True, False, False, True],
@@ -350,7 +350,7 @@ class TestInterpolatedReconstruction:
             sub_size=1,
         )
 
-        grid = aa.MaskedGrid.from_mask(mask=mask)
+        grid = aa.Grid.from_mask(mask=mask)
 
         pixelization_grid = aa.Grid.uniform(
             shape_2d=(3, 3), pixel_scales=1.0, sub_size=1
@@ -382,7 +382,7 @@ class TestInterpolatedReconstruction:
         assert interpolated_errors.in_2d == pytest.approx(np.ones(shape=(5, 5)), 1.0e-4)
         assert interpolated_errors.pixel_scales == pytest.approx((1.0, 1.0), 1.0e-4)
 
-    def test__interpolation_reconsruction__config_is_source_grid__grid_is_zoomed_as_uses_mapper_grid(
+    def test__interp_reconsruction__config_is_source_grid__grid_is_zoomed_as_uses_mapper_grid(
         self
     ):
         conf.instance = aa.conf.Config(
@@ -393,7 +393,7 @@ class TestInterpolatedReconstruction:
         matrix_shape = (3, 3)
 
         mask = aa.Mask.manual(
-            mask_2d=np.array(
+            mask=np.array(
                 [
                     [True, True, True, True, True],
                     [True, True, False, False, True],
@@ -406,7 +406,7 @@ class TestInterpolatedReconstruction:
             sub_size=1,
         )
 
-        grid = aa.MaskedGrid.from_mask(mask=mask)
+        grid = aa.Grid.from_mask(mask=mask)
 
         pixelization_grid = aa.Grid.uniform(
             shape_2d=(3, 3), pixel_scales=1.0, sub_size=1
@@ -474,12 +474,12 @@ class TestInterpolatedReconstruction:
         ).all()
         assert interpolated_reconstruction.pixel_scales == (1.0, 1.0)
 
-    def test__interpolation__manual_shape_2d__uses_input_shape_2d(self):
+    def test__interp__manual_shape_2d__uses_input_shape_2d(self):
 
         matrix_shape = (3, 3)
 
         mask = aa.Mask.manual(
-            mask_2d=np.array(
+            mask=np.array(
                 [
                     [True, True, True, True, True],
                     [True, True, False, False, True],
@@ -492,7 +492,7 @@ class TestInterpolatedReconstruction:
             sub_size=1,
         )
 
-        grid = aa.MaskedGrid.from_mask(mask=mask)
+        grid = aa.Grid.from_mask(mask=mask)
 
         pixelization_grid = aa.Grid.uniform(
             shape_2d=(3, 3), pixel_scales=1.0, sub_size=1
